<h1>Telethon to Pyrogram</h1>
PyPi
Isort
Test
Lint
license
Gitter
Downloads
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

<h4>Simple script for convert telethon session file to pyrogram session file</h4>

<h3>For use:</h3>

1. Clone repo `git clone git@github.com:semenovsd/Telethon-To-Pyrogram.git`
2. Install Telethon and Pyrogram `poetry install` or user pip `pip install Telethon Pyrogram`
3. Run convertor.py `python convertor.py` and follow instructions
